@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2018, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2019, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -30,6 +30,7 @@
 #define MAINWINDOW_H
 
 #include <QWidget>
+#include <QStringList>
 
 class QAbstractButton;
 
@@ -47,12 +48,15 @@ public:
 
 private slots:
     void on_buttonBox_clicked(QAbstractButton *button);
+    void on_infoButton_clicked();
 
 private:
     void showEvent(QShowEvent *) override;
     void closeEvent(QCloseEvent *) override;
+    void checkConfiguration();
 
     Ui::MainWindow *m_ui;
+    QStringList m_errors;
 };
 
 #endif // MAINWINDOW_H
